@@ -249,17 +249,18 @@ class DownloadClient:
         Download items with given DIDs. This function can also download datasets and wildcarded DIDs.
 
         :param items: List of dictionaries. Each dictionary describing an item to download. Keys:
-            did                 - DID string of this file (e.g. 'scope:file.name')
-            filters             - Filter to select DIDs for download. Optional if DID is given
-            rse                 - Optional: rse name (e.g. 'CERN-PROD_DATADISK') or rse expression from where to download
-            no_resolve_archives - Optional: bool indicating whether archives should not be considered for download (Default: False)
-            resolve_archives    - Deprecated: Use no_resolve_archives instead
-            force_scheme        - Optional: force a specific scheme to download this item. (Default: None)
-            base_dir            - Optional: base directory where the downloaded files will be stored. (Default: '.')
-            no_subdir           - Optional: If true, files are written directly into base_dir. (Default: False)
-            nrandom             - Optional: if the DID addresses a dataset, nrandom files will be randomly choosen for download from the dataset
-            ignore_checksum     - Optional: If true, skips the checksum validation between the downloaded file and the rucio catalouge. (Default: False)
-            transfer_timeout    - Optional: Timeout time for the download protocols. (Default: None)
+            did                    - DID string of this file (e.g. 'scope:file.name')
+            filters                - Filter to select DIDs for download. Optional if DID is given
+            rse                    - Optional: rse name (e.g. 'CERN-PROD_DATADISK') or rse expression from where to download
+            no_resolve_archives    - Optional: bool indicating whether archives should not be considered for download (Default: False)
+            resolve_archives       - Deprecated: Use no_resolve_archives instead
+            force_scheme           - Optional: force a specific scheme to download this item. (Default: None)
+            base_dir               - Optional: base directory where the downloaded files will be stored. (Default: '.')
+            no_subdir              - Optional: If true, files are written directly into base_dir. (Default: False)
+            nrandom                - Optional: if the DID addresses a dataset, nrandom files will be randomly choosen for download from the dataset
+            ignore_checksum        - Optional: If true, skips the checksum validation between the downloaded file and the rucio catalouge. (Default: False)
+            transfer_timeout       - Optional: Timeout time for the download protocols. (Default: None)
+            transfer_speed_timeout - Optional: Minimum allowed transfer speed (in KBps). Ignored if transfer_timeout set. Otherwise, used to compute default timeout (Default: 500)
         :param num_threads: Suggestion of number of threads to use for the download. It will be lowered if it's too high.
         :param trace_custom_fields: Custom key value pairs to send with the traces.
         :param traces_copy_out: reference to an external list, where the traces should be uploaded
@@ -434,7 +435,7 @@ class DownloadClient:
         :return: timeout in seconds
         """
         default_transfer_timeout = 360
-        default_transfer_speed_timeout = 1000000  # 1Mbps
+        default_transfer_speed_timeout = 500  # KBps
         # Static additive increment of the speed timeout. To include the static cost of
         # establishing connections and download of small files
         transfer_speed_timeout_static_increment = 60
@@ -451,6 +452,8 @@ class DownloadClient:
         if not transfer_speed_timeout > 0:
             transfer_speed_timeout = default_transfer_speed_timeout
 
+        # Convert from KBytes/s to bytes/s
+        transfer_speed_timeout = transfer_speed_timeout * 1000
         timeout = bytes // transfer_speed_timeout + transfer_speed_timeout_static_increment
         return timeout
 
@@ -577,7 +580,12 @@ class DownloadClient:
             trace['clientState'] = 'DOWNLOAD_ATTEMPT'
             trace['protocol'] = scheme
 
-            logger(logging.INFO, '%sTrying to download with %s from %s: %s ' % (log_prefix, scheme, rse_name, did_str))
+            transfer_timeout = self._compute_actual_transfer_timeout(item)
+            timeout_log_string = ""
+            if transfer_timeout:
+                timeout_log_string = " and timeout of %ds" % transfer_timeout
+
+            logger(logging.INFO, '%sTrying to download with %s%s from %s: %s ' % (log_prefix, scheme, timeout_log_string, rse_name, did_str))
 
             try:
                 protocol = rsemgr.create_protocol(rse, operation='read', scheme=scheme, auth_token=self.auth_token, logger=logger)
@@ -602,7 +610,7 @@ class DownloadClient:
                 start_time = time.time()
 
                 try:
-                    protocol.get(pfn, temp_file_path, transfer_timeout=self._compute_actual_transfer_timeout(item))
+                    protocol.get(pfn, temp_file_path, transfer_timeout=transfer_timeout)
                     success = True
                 except Exception as error:
                     logger(logging.DEBUG, error)
@@ -1063,9 +1071,9 @@ class DownloadClient:
 
                     cur_transfer_speed_timeout = options.setdefault('transfer_speed_timeout', None)
                     if cur_transfer_speed_timeout is not None and new_transfer_speed_timeout is not None:
-                        options['transfer_speed_timeout'] = min(int(cur_transfer_speed_timeout), int(new_transfer_speed_timeout))
+                        options['transfer_speed_timeout'] = min(float(cur_transfer_speed_timeout), float(new_transfer_speed_timeout))
                     elif new_transfer_speed_timeout is not None:
-                        options['transfer_speed_timeout'] = int(new_transfer_speed_timeout)
+                        options['transfer_speed_timeout'] = float(new_transfer_speed_timeout)
 
                     if resolved_did_str not in all_resolved_did_strs:
                         resolved_dids.append({'scope': did_scope, 'name': did_name})
@@ -1144,12 +1152,13 @@ class DownloadClient:
             # filtering out tape sources
             if self.is_tape_excluded:
                 for file_item in file_items:
-                    sources = file_item['sources']
-                    for src in file_item['sources']:
+                    unfiltered_sources = copy.copy(file_item['sources'])
+                    for src in unfiltered_sources:
                         if src in tape_rses:
-                            sources.remove(src)
-                    if not sources:
-                        logger(logging.WARNING, 'Requested did {} has only replicas on tape. No files will be download.'.format(file_item['did']))
+                            file_item['sources'].remove(src)
+                    if unfiltered_sources and not file_item['sources']:
+                        logger(logging.WARNING, 'The requested DID {} only has replicas on tape. Direct download from tape is prohibited. '
+                                                'Please request a transfer to a non-tape endpoint.'.format(file_item['did']))
 
             nrandom = item.get('nrandom')
             if nrandom:
